pub fn load_key(key_path: &Path) -> Result<PrivateKey>Expand description
Load an existing SSH private key from disk.
Errors
Returns an error if the file cannot be read or parsed.
pub fn load_key(key_path: &Path) -> Result<PrivateKey>Load an existing SSH private key from disk.
Returns an error if the file cannot be read or parsed.